@@ -1,5 +1,6 @@
 import os
 
+
 import numpy as np
 import pandas as pd
 
@@ -37,11 +38,10 @@ class Analysis_capture_virus(Step, AnalysisMixin):
         self.virus_file = args.virus_file
         self.umi_threshold = args.umi_threshold
 
-        # out files
         self.virus_tsne_file = f'{self.outdir}/{self.sample}_virus_tsne.tsv'
         self.otsu_virus_file = f'{self.outdir}/{self.sample}_otsu_count.tsv'
         self.otsu_plot = f'{self.outdir}/{self.sample}_otsu_plot.png'
-
+    
     def run(self):
         if self.umi_threshold == 'otsu':
             self.otsu_thresh()
@@ -62,6 +62,23 @@ class Analysis_capture_virus(Step, AnalysisMixin):
     def get_virus_tsne(self, virus_df):
         virus_tsne_df = pd.merge(self.tsne_df, virus_df, on="barcode", how="left")
         virus_tsne_df.to_csv(self.virus_tsne_file, sep='\t')
+        
+        #get the sum of virus
+        total_virus = virus_tsne_df.loc[:,"tag"].count()
+        #get the sum of virus in each cluster
+        cluster_virus = virus_tsne_df.groupby("cluster")["tag"].count()
+        #Total cell each cluster
+        total_cell_cluster = virus_tsne_df.groupby("cluster")["barcode"].count()
+        #add sum of virus to metric
+        self.add_metric(name = 'Number of Cells with Virus',value = f'{total_virus}({round(total_virus/sum(total_cell_cluster),2)}%)')
+        #add sum of virus in each cluster to metric
+        cluster = 1    
+        for num_virus in cluster_virus:
+            total_cell = total_cell_cluster[cluster]
+            self.add_metric(name = f'Cluster_{cluster}',value = f'{num_virus}({round(num_virus/total_cell,2)}%)')
+            cluster += 1
+
+
         virus_tsne_df["UMI"] = virus_tsne_df["UMI"].fillna(0)
         tSNE_1 = list(virus_tsne_df.tSNE_1)
         tSNE_2 = list(virus_tsne_df.tSNE_2)
@@ -83,4 +100,4 @@ class Analysis_capture_virus(Step, AnalysisMixin):
             value=threshold,
         )
         df_thresh = df_virus[df_virus["UMI"] >= threshold]
-        df_thresh.to_csv(self.otsu_virus_file, sep='\t')
+        df_thresh.to_csv(self.otsu_virus_file, sep='\t')
\ No newline at end of file
